@@ -1,6 +1,7 @@
 import abc
+from typing import List
 
-from substra.sdk.config import BackendType
+from substra.sdk.schemas import BackendType
 
 
 class BaseBackend(abc.ABC):
@@ -30,11 +31,11 @@ class BaseBackend(abc.ABC):
         raise NotImplementedError
 
     @abc.abstractmethod
-    def add_compute_plan_tuples(self, spec, spec_options):
+    def add_compute_plan_tasks(self, spec, spec_options):
         raise NotImplementedError
 
     @abc.abstractmethod
-    def link_dataset_with_data_samples(self, dataset_key, data_sample_keys):
+    def link_dataset_with_data_samples(self, dataset_key, data_sample_keys) -> List[str]:
         raise NotImplementedError
 
     @abc.abstractmethod
