@@ -14,7 +14,6 @@ from typing import List
 from typing import Optional
 from typing import Tuple
 from typing import Type
-from typing import Union
 
 from substra.sdk import exceptions
 from substra.sdk import fs
@@ -23,6 +22,12 @@ from substra.sdk import schemas
 from substra.sdk.backends.local import dal
 from substra.sdk.backends.local.compute import spawner
 from substra.sdk.backends.local.compute.spawner import BaseSpawner
+from substra.sdk.backends.local.compute.spawner.base import VOLUME_CLI_ARGS
+from substra.sdk.backends.local.compute.spawner.base import VOLUME_INPUTS
+from substra.sdk.backends.local.compute.spawner.base import VOLUME_OUTPUTS
+
+TPL_VOLUME_INPUTS = "${" + VOLUME_INPUTS + "}"
+TPL_VOLUME_OUTPUTS = "${" + VOLUME_OUTPUTS + "}"
 
 
 class TaskResource(dict):
@@ -112,42 +117,24 @@ class Worker:
         cmd_line_inputs,
         output_id_filename,
     ):
-        command_template = ""
+        task_properties = {"rank": task.rank}
+        command_template = ["--task-properties", json.dumps(task_properties, default=str)]
 
         cmd_line_outputs: List[TaskResource] = [
-            TaskResource(id=output_id, value="${_VOLUME_OUTPUTS}/" f"{filename}", multiple=False)
+            TaskResource(id=output_id, value=f"{TPL_VOLUME_OUTPUTS}/{filename}", multiple=False)
             for output_id, filename in output_id_filename.items()
         ]
 
-        if isinstance(task, models.Testtuple):
-            command_template += " --opener-path ${_VOLUME_INPUTS}" f"/{Filenames.OPENER}"
-            command_template += " --output-perf-path " f"/{cmd_line_outputs[0]['value']}"
-        else:
-            if not isinstance(task, models.Predicttuple):
-                command_template += f" --rank {task.rank}"
-            command_template += (
-                " --inputs "
-                + "'"
-                + json.dumps(cmd_line_inputs, default=str)
-                + "'"
-                + " --outputs "
-                + "'"
-                + json.dumps(cmd_line_outputs, default=str)
-                + "'"
-            )
+        command_template += [
+            "--inputs",
+            json.dumps(cmd_line_inputs, default=str),
+            "--outputs",
+            json.dumps(cmd_line_outputs, default=str),
+        ]
         return command_template
 
     def _prepare_artifact_input(self, task_input, input_volume, multiple):
-        in_task, _ = self._get_asset_unknown_type(
-            asset_key=task_input.parent_task_key,
-            possible_types=[
-                schemas.Type.Aggregatetuple,
-                schemas.Type.CompositeTraintuple,
-                schemas.Type.Predicttuple,
-                schemas.Type.Testtuple,
-                schemas.Type.Traintuple,
-            ],
-        )
+        in_task = self._db.get(schemas.Type.Task, task_input.parent_task_key)
         input_artifact = in_task.outputs[task_input.parent_task_output_identifier].value
         assert isinstance(
             input_artifact, models.OutModel
@@ -156,9 +143,7 @@ class Worker:
         path_to_input = input_volume / filename
         Path(input_artifact.address.storage_address).link_to(path_to_input)
 
-        return TaskResource(
-            id=task_input.identifier, value=str(Path("${_VOLUME_INPUTS}") / filename), multiple=multiple
-        )
+        return TaskResource(id=task_input.identifier, value=f"{TPL_VOLUME_INPUTS}/{filename}", multiple=multiple)
 
     def _prepare_dataset_input(
         self, dataset: models.Dataset, task_input: models.InputRef, input_volume: str, multiple: bool
@@ -166,16 +151,18 @@ class Worker:
         path_to_opener = input_volume / Filenames.OPENER.value
         Path(dataset.opener.storage_address).link_to(path_to_opener)
         return TaskResource(
-            id=task_input.identifier, value=str(Path("${_VOLUME_INPUTS}") / Filenames.OPENER.value), multiple=multiple
+            id=task_input.identifier,
+            value=f"{TPL_VOLUME_INPUTS}/{Filenames.OPENER.value}",
+            multiple=multiple,
         )
 
     def _prepare_datasample_input(
         self, datasample_input_refs: List[models.InputRef], datasamples: List[models.DataSample], multiple: bool
     ) -> Tuple[List[TaskResource], Dict[str, str]]:
-        task_resources = list()
+        task_resources = []
         data_sample_paths = dict()
         for datasample_input, datasample in zip(datasample_input_refs, datasamples):
-            datasample_path_arg = str(Path("${_VOLUME_INPUTS}") / datasample_input.asset_key)
+            datasample_path_arg = f"{TPL_VOLUME_INPUTS}/{datasample_input.asset_key}"
             task_resources.append(
                 TaskResource(id=datasample_input.identifier, value=str(datasample_path_arg), multiple=multiple)
             )
@@ -190,72 +177,48 @@ class Worker:
         datasample_input_refs: List[models.InputRef],
         multiple: bool,
     ) -> Tuple[str, List[TaskResource], Optional[Dict[str, str]]]:
-        command_template = ""
-        datasample_task_resources = list()
+        command_template = []
+        datasample_task_resources = []
         data_sample_paths = None
 
         if len(datasamples) == 0:
             pass
         elif dataset is not None and not self._db.is_local(dataset.key, schemas.Type.Dataset):
             # Hybrid mode
-            command_template += " --fake-data"
-            command_template += f" --n-fake-samples {len(datasample_input_refs)}"
+            command_template += ["--fake-data"]
+            command_template += ["--n-fake-samples", len(datasample_input_refs)]
         else:
             datasample_task_resources, data_sample_paths = self._prepare_datasample_input(
                 datasample_input_refs=datasample_input_refs, datasamples=datasamples, multiple=multiple
             )
-            if isinstance(task, models.Testtuple):
-                data_sample_paths_arg_str = " ".join([task_res["value"] for task_res in datasample_task_resources])
-                command_template += f" --data-sample-paths {data_sample_paths_arg_str}"
 
         return command_template, datasample_task_resources, data_sample_paths
 
-    def _update_deprecated_fields(self, task, value: Union[float, models.OutModel], algo_key: str):
-        if isinstance(task, models.Aggregatetuple):
-            task.aggregate.models = [value]
-        elif isinstance(task, models.CompositeTraintuple):
-            if task.composite.models is None:
-                task.composite.models = list()
-            task.composite.models.append(value)
-        elif isinstance(task, models.Predicttuple):
-            task.predict.models = [value]
-        elif isinstance(task, models.Testtuple):
-            task.test.perfs[algo_key] = value
-        elif isinstance(task, models.Traintuple):
-            task.train.models = [value]
-        else:
-            raise ValueError(f"Unsupported type of task {type(task)}")
-
     def _save_output(
         self,
         task,
-        algo_output: models.AlgoOutput,
+        function_output: models.FunctionOutput,
         output_id_filename: Dict[str, str],
         output_volume: str,
-        algo_key: str,
+        function_key: str,
     ) -> bool:
         update_live_performances = False
-        if algo_output.multiple:
+        if function_output.multiple:
             raise NotImplementedError("Multiple output value is not supported yet.")
-        filename = output_id_filename[algo_output.identifier]
+        filename = output_id_filename[function_output.identifier]
         tmp_path = output_volume / filename
         output_dir = _mkdir(self._local_worker_dir / "outputs" / task.key)
         output_path = output_dir / filename
         shutil.copy(tmp_path, output_path)
 
-        if algo_output.kind == schemas.AssetKind.performance:
+        if function_output.kind == schemas.AssetKind.performance:
             update_live_performances = True
             perf = json.loads(output_path.read_text())["all"]
-            task.outputs[algo_output.identifier].value = perf
+            task.outputs[function_output.identifier].value = perf
             value = perf
-        elif algo_output.kind == schemas.AssetKind.model:
-            category = models.ModelType.simple
-            if algo_output.identifier == "local":
-                category = models.ModelType.head
-
+        elif function_output.kind == schemas.AssetKind.model:
             value = models.OutModel(
                 key=str(uuid.uuid4()),
-                category=category,
                 compute_task_key=task.key,
                 address=models.InModel(
                     checksum=fs.hash_file(output_path),
@@ -263,37 +226,36 @@ class Worker:
                 ),
                 creation_date=datetime.datetime.now(),
                 owner=task.owner,
-                permissions=task.outputs[algo_output.identifier].permissions,
+                permissions=task.outputs[function_output.identifier].permissions,
             )
-            task.outputs[algo_output.identifier].value = value
+            task.outputs[function_output.identifier].value = value
             self._db.add(value)
 
         else:
-            raise ValueError(f"This asset kind is not supported for algo output: {algo_output.kind}")
+            raise ValueError(f"This asset kind is not supported for function output: {function_output.kind}")
 
-        self._update_deprecated_fields(task=task, value=value, algo_key=algo_key)
         return update_live_performances
 
-    def schedule_task(self, task: models._GenericTraintuple):
+    def schedule_task(self, task: models.Task):
         """Execute the task
 
         Args:
             task: Task to execute
         """
         with self._context(task.key) as task_dir:
-
             task.status = models.Status.doing
             task.start_date = datetime.datetime.now()
 
-            algo = self._db.get_with_files(schemas.Type.Algo, task.algo.key)
-            input_multiplicity = {i.identifier: i.multiple for i in algo.inputs}
+            function = self._db.get_with_files(schemas.Type.Function, task.function.key)
+            input_multiplicity = {i.identifier: i.multiple for i in function.inputs}
             compute_plan = self._db.get(schemas.Type.ComputePlan, task.compute_plan_key)
 
-            command_template: str = ""
+            command_template = []
 
             volumes = {
-                "_VOLUME_INPUTS": _mkdir(task_dir / "inputs"),
-                "_VOLUME_OUTPUTS": _mkdir(task_dir / "outputs"),
+                VOLUME_INPUTS: _mkdir(task_dir / "inputs"),
+                VOLUME_OUTPUTS: _mkdir(task_dir / "outputs"),
+                VOLUME_CLI_ARGS: _mkdir(task_dir / "cli-args"),
             }
 
             cmd_line_inputs: List[TaskResource] = []
@@ -301,8 +263,8 @@ class Worker:
             dataset: Optional[models.Dataset] = None
             data_sample_paths: Optional[Dict[str, str]] = None
 
-            datasample_input_refs: List[models.InputRef] = list()
-            datasamples: List[models.DataSample] = list()
+            datasample_input_refs: List[models.InputRef] = []
+            datasamples: List[models.DataSample] = []
 
             # Prepare inputs
             for task_input in task.inputs:
@@ -311,12 +273,10 @@ class Worker:
                 if task_input.parent_task_key is not None:
                     task_resource = self._prepare_artifact_input(
                         task_input=task_input,
-                        input_volume=volumes["_VOLUME_INPUTS"],
+                        input_volume=volumes[VOLUME_INPUTS],
                         multiple=multiple,
                     )
                     cmd_line_inputs.append(task_resource)
-                    if isinstance(task, models.Testtuple):
-                        command_template += " --input-predictions-path " f"{task_resource['value']}"
                 else:
                     asset, asset_type = self._get_asset_unknown_type(
                         asset_key=task_input.asset_key, possible_types=[schemas.Type.DataSample, schemas.Type.Dataset]
@@ -332,7 +292,7 @@ class Worker:
                             self._prepare_dataset_input(
                                 dataset=dataset,
                                 task_input=task_input,
-                                input_volume=volumes["_VOLUME_INPUTS"],
+                                input_volume=volumes[VOLUME_INPUTS],
                                 multiple=multiple,
                             )
                         )
@@ -359,14 +319,14 @@ class Worker:
                 cmd_line_inputs=cmd_line_inputs,
                 output_id_filename=output_id_filename,
             )
-            command_template += " --log-level warning"
+            command_template += ["--log-level", "warning"]
 
             # Task execution
-            container_name = f"algo-{algo.algorithm.checksum}"
+            container_name = f"function-{function.function.checksum}"
             self._spawner.spawn(
                 container_name,
-                str(algo.algorithm.storage_address),
-                command_template=string.Template(command_template),
+                str(function.function.storage_address),
+                command_args_tpl=[string.Template(str(part)) for part in command_template],
                 local_volumes=volumes,
                 data_sample_paths=data_sample_paths,
                 envs=None,
@@ -374,13 +334,13 @@ class Worker:
 
             # Save the outputs
             update_live_performances = False
-            for algo_output in algo.outputs:
+            for function_output in function.outputs:
                 update_live_performances = self._save_output(
                     task=task,
-                    algo_output=algo_output,
+                    function_output=function_output,
                     output_id_filename=output_id_filename,
-                    output_volume=volumes["_VOLUME_OUTPUTS"],
-                    algo_key=algo.key,
+                    output_volume=volumes[VOLUME_OUTPUTS],
+                    function_key=function.key,
                 )
 
             # Set status
