@@ -6,13 +6,13 @@ from typing import ClassVar
 from typing import Dict
 from typing import List
 from typing import Optional
+from typing import Type
 from typing import Union
 
 import pydantic
 from pydantic import AnyUrl
 from pydantic import DirectoryPath
 from pydantic import FilePath
-from pydantic import root_validator
 from pydantic.fields import Field
 
 from substra.sdk import schemas
@@ -54,14 +54,6 @@ class ComputePlanStatus(str, enum.Enum):
     empty = "PLAN_STATUS_EMPTY"
 
 
-class ModelType(str, enum.Enum):
-    """Model type"""
-
-    unknown = "MODEL_UNKNOWN"
-    head = "MODEL_HEAD"
-    simple = "MODEL_SIMPLE"
-
-
 class TaskErrorType(str, enum.Enum):
     """Types of errors that can occur in a task"""
 
@@ -113,7 +105,7 @@ class _Model(schemas._PydanticConfig, abc.ABC):
     @staticmethod
     def allowed_filters() -> List[str]:
         """allowed fields to filter on"""
-        return list()
+        return []
 
 
 class DataSample(_Model):
@@ -124,14 +116,12 @@ class DataSample(_Model):
     data_manager_keys: Optional[List[str]]
     path: Optional[DirectoryPath]
     creation_date: datetime
-    # The backend does not return this but it is needed for link_dataset_with_data_samples
-    test_only: bool = False
 
     type_: ClassVar[str] = schemas.Type.DataSample
 
     @staticmethod
     def allowed_filters() -> List[str]:
-        return ["key", "owner", "compute_plan_key", "algo_key", "dataset_key", "test_only"]
+        return ["key", "owner", "compute_plan_key", "function_key", "dataset_key"]
 
 
 class _File(schemas._PydanticConfig):
@@ -149,8 +139,7 @@ class Dataset(_Model):
     owner: str
     permissions: Permissions
     type: str
-    train_data_sample_keys: List[str] = list()
-    test_data_sample_keys: List[str] = list()
+    data_sample_keys: List[str] = []
     opener: _File
     description: _File
     metadata: Dict[str, str]
@@ -161,37 +150,36 @@ class Dataset(_Model):
 
     @staticmethod
     def allowed_filters() -> List[str]:
-        return ["key", "name", "owner", "permissions", "compute_plan_key", "algo_key", "data_sample_key"]
+        return ["key", "name", "owner", "permissions", "compute_plan_key", "function_key", "data_sample_key"]
 
 
-class AlgoInput(_Model):
+class FunctionInput(_Model):
     identifier: str
     kind: schemas.AssetKind
     optional: bool
     multiple: bool
 
 
-class AlgoOutput(_Model):
+class FunctionOutput(_Model):
     identifier: str
     kind: schemas.AssetKind
     multiple: bool
 
 
-class Algo(_Model):
+class Function(_Model):
     key: str
     name: str
     owner: str
     permissions: Permissions
     metadata: Dict[str, str]
-    category: schemas.AlgoCategory
     creation_date: datetime
-    inputs: List[AlgoInput]
-    outputs: List[AlgoOutput]
+    inputs: List[FunctionInput]
+    outputs: List[FunctionOutput]
 
     description: _File
-    algorithm: _File
+    function: _File
 
-    type_: ClassVar[str] = schemas.Type.Algo
+    type_: ClassVar[str] = schemas.Type.Function
 
     @staticmethod
     def allowed_filters() -> List[str]:
@@ -202,13 +190,13 @@ class Algo(_Model):
         if isinstance(v, dict):
             # Transform the inputs dict to a list
             return [
-                AlgoInput(
+                FunctionInput(
                     identifier=identifier,
-                    kind=algo_input["kind"],
-                    optional=algo_input["optional"],
-                    multiple=algo_input["multiple"],
+                    kind=function_input["kind"],
+                    optional=function_input["optional"],
+                    multiple=function_input["multiple"],
                 )
-                for identifier, algo_input in v.items()
+                for identifier, function_input in v.items()
             ]
         else:
             return v
@@ -218,26 +206,26 @@ class Algo(_Model):
         if isinstance(v, dict):
             # Transform the outputs dict to a list
             return [
-                AlgoOutput(identifier=identifier, kind=algo_output["kind"], multiple=algo_output["multiple"])
-                for identifier, algo_output in v.items()
+                FunctionOutput(
+                    identifier=identifier, kind=function_output["kind"], multiple=function_output["multiple"]
+                )
+                for identifier, function_output in v.items()
             ]
         else:
             return v
 
 
 class InModel(schemas._PydanticConfig):
-    """In model of a traintuple, aggregate or composite traintuple"""
+    """In model of a task"""
 
     checksum: str
     storage_address: UriPath
 
 
 class OutModel(schemas._PydanticConfig):
-    """Out model of a traintuple, aggregate tuple or out trunk
-    model of a composite traintuple"""
+    """Out model of a task"""
 
     key: str
-    category: ModelType  # TODO: delete this field
     compute_task_key: str
     address: Optional[InModel]
     permissions: Permissions
@@ -272,26 +260,23 @@ class ComputeTaskOutput(schemas._PydanticConfig):
         allow_population_by_field_name = True
 
 
-class _GenericTraintuple(_Model):
+class SummaryTask(_Model):
     key: str
-    category: schemas.TaskCategory
-    algo: Algo
+    function: Function
     owner: str
     compute_plan_key: str
     metadata: Dict[str, str]
     status: Status
     worker: str
     rank: Optional[int]
-    parent_task_keys: List[str]
-    parent_tasks: Optional[List[Union["Traintuple", "CompositeTraintuple", "Aggregatetuple", "Predicttuple"]]] = list()
-    inputs: List[InputRef]
-    outputs: Dict[str, ComputeTaskOutput]
     tag: str
     creation_date: datetime
     start_date: Optional[datetime]
     end_date: Optional[datetime]
     error_type: Optional[TaskErrorType] = None
 
+    type_: ClassVar[Type] = schemas.Type.Task
+
     @staticmethod
     def allowed_filters() -> List[str]:
         return [
@@ -302,105 +287,16 @@ class _GenericTraintuple(_Model):
             "status",
             "metadata",
             "compute_plan_key",
-            "algo_key",
-            "dataset_key",
-            "data_sample_key",
+            "function_key",
         ]
 
 
-def check_data_manager_key(cls, values):
-    if values.get("data_manager"):
-        assert values["data_manager_key"] == values["data_manager"].key, "data_manager does not match data_manager_key"
-    return values
+class Task(SummaryTask):
+    inputs: List[InputRef]
+    outputs: Dict[str, ComputeTaskOutput]
 
 
-class _Composite(schemas._PydanticConfig):
-    data_manager_key: str
-    data_manager: Optional[Dataset] = None
-    data_sample_keys: List[str]
-    models: Optional[List[OutModel]]
-
-    _check_data_manager_key = root_validator(allow_reuse=True)(check_data_manager_key)
-
-
-class _Train(schemas._PydanticConfig):
-    data_manager_key: str
-    data_manager: Optional[Dataset] = None
-    data_sample_keys: List[str]
-    models: Optional[List[OutModel]]
-
-    _check_data_manager_key = root_validator(allow_reuse=True)(check_data_manager_key)
-
-
-class _Aggregate(schemas._PydanticConfig):
-    models: Optional[List[OutModel]]
-
-
-class _Predict(schemas._PydanticConfig):
-    data_manager_key: str
-    data_manager: Optional[Dataset] = None
-    data_sample_keys: List[str]
-    models: Optional[List[OutModel]]
-
-    _check_data_manager_key = root_validator(allow_reuse=True)(check_data_manager_key)
-
-
-class _Test(schemas._PydanticConfig):
-    data_manager_key: str
-    data_manager: Optional[Dataset] = None
-    data_sample_keys: List[str]
-    perfs: Optional[Dict[str, float]]
-
-    _check_data_manager_key = root_validator(allow_reuse=True)(check_data_manager_key)
-
-
-class Traintuple(_GenericTraintuple):
-    """Traintuple"""
-
-    train: _Train
-    type_: ClassVar[str] = schemas.Type.Traintuple
-
-
-class Aggregatetuple(_GenericTraintuple):
-    """Aggregatetuple"""
-
-    aggregate: _Aggregate
-    type_: ClassVar[str] = schemas.Type.Aggregatetuple
-
-
-class CompositeTraintuple(_GenericTraintuple):
-    """CompositeTraintuple"""
-
-    composite: _Composite
-    type_: ClassVar[str] = schemas.Type.CompositeTraintuple
-
-
-class Predicttuple(_GenericTraintuple):
-    """Predicttuple"""
-
-    predict: _Predict
-    type_: ClassVar[str] = schemas.Type.Predicttuple
-
-
-_GenericTraintuple.update_forward_refs()
-Predicttuple.update_forward_refs()
-Traintuple.update_forward_refs()
-Aggregatetuple.update_forward_refs()
-CompositeTraintuple.update_forward_refs()
-
-
-class Testtuple(_GenericTraintuple):
-    """Testtuple"""
-
-    test: _Test
-    type_: ClassVar[str] = schemas.Type.Testtuple
-
-
-class FailedTuple(_Model):
-    """Info on failed tuple."""
-
-    key: str
-    category: str
+Task.update_forward_refs()
 
 
 class ComputePlan(_Model):
@@ -418,37 +314,47 @@ class ComputePlan(_Model):
     canceled_count: int = 0
     failed_count: int = 0
     done_count: int = 0
-    failed_task: Optional[FailedTuple]
-    delete_intermediary_models: bool = False
+    failed_task_key: Optional[str]
     status: ComputePlanStatus
     creation_date: datetime
     start_date: Optional[datetime]
     end_date: Optional[datetime]
     estimated_end_date: Optional[datetime]
     duration: Optional[int]
+    creator: Optional[str]
 
     type_: ClassVar[str] = schemas.Type.ComputePlan
 
     @staticmethod
     def allowed_filters() -> List[str]:
-        return ["key", "name", "owner", "worker", "status", "metadata", "algo_key", "dataset_key", "data_sample_key"]
+        return [
+            "key",
+            "name",
+            "owner",
+            "worker",
+            "status",
+            "metadata",
+            "function_key",
+            "dataset_key",
+            "data_sample_key",
+        ]
 
 
 class Performances(_Model):
     """Performances of the different compute tasks of a compute plan"""
 
-    compute_plan_key: List[str] = list()
-    compute_plan_tag: List[str] = list()
-    compute_plan_status: List[str] = list()
-    compute_plan_start_date: List[datetime] = list()
-    compute_plan_end_date: List[datetime] = list()
-    compute_plan_metadata: List[dict] = list()
-    worker: List[str] = list()
-    testtuple_key: List[str] = list()
-    metric_name: List[str] = list()
-    testtuple_rank: List[int] = list()
-    round_idx: List[int] = list()
-    performance: List[float] = list()
+    compute_plan_key: List[str] = []
+    compute_plan_tag: List[str] = []
+    compute_plan_status: List[str] = []
+    compute_plan_start_date: List[datetime] = []
+    compute_plan_end_date: List[datetime] = []
+    compute_plan_metadata: List[dict] = []
+    worker: List[str] = []
+    task_key: List[str] = []
+    function_name: List[str] = []
+    task_rank: List[int] = []
+    round_idx: List[int] = []
+    performance: List[float] = []
 
 
 class Organization(schemas._PydanticConfig):
@@ -476,15 +382,12 @@ class OrganizationInfo(schemas._PydanticConfig):
 
 
 SCHEMA_TO_MODEL = {
-    schemas.Type.Aggregatetuple: Aggregatetuple,
-    schemas.Type.Algo: Algo,
-    schemas.Type.CompositeTraintuple: CompositeTraintuple,
+    schemas.Type.Task: Task,
+    schemas.Type.SummaryTask: SummaryTask,
+    schemas.Type.Function: Function,
     schemas.Type.ComputePlan: ComputePlan,
     schemas.Type.DataSample: DataSample,
     schemas.Type.Dataset: Dataset,
-    schemas.Type.Predicttuple: Predicttuple,
-    schemas.Type.Testtuple: Testtuple,
-    schemas.Type.Traintuple: Traintuple,
     schemas.Type.Organization: Organization,
     schemas.Type.Model: OutModel,
 }
