@@ -15,9 +15,16 @@ from substra.sdk import utils
 
 _SERVER_NAMES = {
     "dataset": "data_manager",
+    "summary_task": "task",
 }
 
 
+class BackendType(str, enum.Enum):
+    REMOTE = "remote"
+    LOCAL_DOCKER = "docker"
+    LOCAL_SUBPROCESS = "subprocess"
+
+
 class StaticInputIdentifier(str, enum.Enum):
     chainkeys = "chainkeys"
     datasamples = "datasamples"
@@ -40,17 +47,14 @@ class AssetKind(str, enum.Enum):
 
 
 class Type(enum.Enum):
-    Algo = "algo"
+    Function = "function"
     DataSample = "data_sample"
     Dataset = "dataset"
     Model = "model"
-    Predicttuple = "predicttuple"
-    Testtuple = "testtuple"
-    Traintuple = "traintuple"
-    Aggregatetuple = "aggregatetuple"
-    CompositeTraintuple = "composite_traintuple"
     ComputePlan = "compute_plan"
     Organization = "organization"
+    Task = "task"
+    SummaryTask = "summary_task"
 
     def to_server(self):
         """Returns the name used to identify the asset on the backend."""
@@ -61,28 +65,6 @@ class Type(enum.Enum):
         return self.name
 
 
-class AlgoCategory(str, enum.Enum):
-    """Algo category"""
-
-    unknown = "ALGO_UNKNOWN"
-    simple = "ALGO_SIMPLE"
-    composite = "ALGO_COMPOSITE"
-    aggregate = "ALGO_AGGREGATE"
-    metric = "ALGO_METRIC"
-    predict = "ALGO_PREDICT"
-
-
-class TaskCategory(str, enum.Enum):
-    """Task category"""
-
-    unknown = "TASK_UNKNOWN"
-    train = "TASK_TRAIN"
-    aggregate = "TASK_AGGREGATE"
-    composite = "TASK_COMPOSITE"
-    predict = "TASK_PREDICT"
-    test = "TASK_TEST"
-
-
 class _PydanticConfig(pydantic.BaseModel):
     """Shared configuration for all schemas here"""
 
@@ -148,7 +130,6 @@ class DataSampleSpec(_Spec):
 
     path: Optional[pathlib.Path]  # Path to the data sample if only one
     paths: Optional[List[pathlib.Path]]  # Path to the data samples if several
-    test_only: bool  # If the data sample is for train or test
     data_manager_keys: typing.List[str]
 
     type_: typing.ClassVar[Type] = Type.DataSample
@@ -211,81 +192,35 @@ class ComputeTaskOutputSpec(_PydanticConfig):
         allow_population_by_field_name = True
 
 
-class _ComputePlanComputeTaskSpec(_Spec):
-    """Specification of a compute task inside a compute plan specification"""
+class ComputePlanTaskSpec(_Spec):
+    """Specification of a compute task inside a compute plan specification
 
-    algo_key: str
+    note : metadata field does not accept strings containing '__' as dict key
+    """
+
+    task_id: str
+    function_key: str
+    worker: str
     tag: Optional[str]
     metadata: Optional[Dict[str, str]]
     inputs: Optional[List[InputRef]]
     outputs: Optional[Dict[str, ComputeTaskOutputSpec]]
 
 
-class ComputePlanTraintupleSpec(_ComputePlanComputeTaskSpec):
-    """Specification of a traintuple inside a compute
-    plan specification"""
-
-    data_manager_key: str
-    train_data_sample_keys: List[str]
-    traintuple_id: str
-    in_models_ids: Optional[List[str]]
-
-
-class ComputePlanAggregatetupleSpec(_ComputePlanComputeTaskSpec):
-    """Specification of an aggregate tuple inside a compute
-    plan specification"""
-
-    aggregatetuple_id: str
-    worker: str
-    in_models_ids: Optional[List[str]]
-
-
-class ComputePlanCompositeTraintupleSpec(_ComputePlanComputeTaskSpec):
-    """Specification of a composite traintuple inside a compute
-    plan specification"""
-
-    composite_traintuple_id: str
-    data_manager_key: str
-    train_data_sample_keys: List[str]
-    in_head_model_id: Optional[str]
-    in_trunk_model_id: Optional[str]
-
-
-class ComputePlanPredicttupleSpec(_ComputePlanComputeTaskSpec):
-    """Specification of a predict tuple inside a compute
-    plan specification"""
-
-    predicttuple_id: str
-    traintuple_id: str
-    data_manager_key: str
-    test_data_sample_keys: List[str]
-
-
-class ComputePlanTesttupleSpec(_ComputePlanComputeTaskSpec):
-    """Specification of a testtuple inside a compute
-    plan specification"""
-
-    predicttuple_id: str
-    data_manager_key: str
-    test_data_sample_keys: List[str]
-
-
 class _BaseComputePlanSpec(_Spec):
     key: str
-    traintuples: Optional[List[ComputePlanTraintupleSpec]]
-    composite_traintuples: Optional[List[ComputePlanCompositeTraintupleSpec]]
-    aggregatetuples: Optional[List[ComputePlanAggregatetupleSpec]]
-    predicttuples: Optional[List[ComputePlanPredicttupleSpec]]
-    testtuples: Optional[List[ComputePlanTesttupleSpec]]
+    tasks: Optional[List[ComputePlanTaskSpec]]
 
 
 class ComputePlanSpec(_BaseComputePlanSpec):
-    """Specification for creating a compute plan"""
+    """Specification for creating a compute plan
+
+    note : metadata field does not accept strings containing '__' as dict key
+    """
 
     key: str = pydantic.Field(default_factory=lambda: str(uuid.uuid4()))
     tag: Optional[str]
     name: str
-    clean_models: Optional[bool]
     metadata: Optional[Dict[str, str]]
 
     type_: typing.ClassVar[Type] = Type.ComputePlan
@@ -299,8 +234,8 @@ class ComputePlanSpec(_BaseComputePlanSpec):
         yield data, None
 
 
-class UpdateComputePlanTuplesSpec(_BaseComputePlanSpec):
-    """Specification for updating a compute plan's tuples"""
+class UpdateComputePlanTasksSpec(_BaseComputePlanSpec):
+    """Specification for updating a compute plan's tasks"""
 
     pass
 
@@ -314,7 +249,10 @@ class UpdateComputePlanSpec(_Spec):
 
 
 class DatasetSpec(_Spec):
-    """Specification for creating a dataset"""
+    """Specification for creating a dataset
+
+    note : metadata field does not accept strings containing '__' as dict key
+    """
 
     name: str
     data_opener: pathlib.Path  # Path to the data opener
@@ -341,7 +279,7 @@ class UpdateDatasetSpec(_Spec):
     type_: typing.ClassVar[Type] = Type.Dataset
 
 
-class AlgoInputSpec(_Spec):
+class FunctionInputSpec(_Spec):
     identifier: str
     multiple: bool
     optional: bool
@@ -350,34 +288,33 @@ class AlgoInputSpec(_Spec):
     @pydantic.root_validator
     def _check_identifiers(cls, values):  # noqa: N805
         """Checks that the multiplicity and the optionality of a data manager is always set to False"""
-        if values.get("kind") == AssetKind.data_manager:
-            if values.get("multiple"):
+        if values["kind"] == AssetKind.data_manager:
+            if values["multiple"]:
                 raise ValueError("Data manager input can't be multiple.")
-            if values.get("optional"):
+            if values["optional"]:
                 raise ValueError("Data manager input can't be optional.")
-            if values.get("identifier") != StaticInputIdentifier.opener:
+            if values["identifier"] != StaticInputIdentifier.opener:
                 raise ValueError(
                     f"Data manager input identifier must be `{StaticInputIdentifier.opener}` "
                     f"but was set to {values['identifier']}"
                 )
-        elif values.get("kind") == AssetKind.data_sample:
-            if values.get("identifier") != StaticInputIdentifier.datasamples:
+        elif values["kind"] == AssetKind.data_sample:
+            if values["identifier"] != StaticInputIdentifier.datasamples:
                 raise ValueError(
                     f"Data sample input identifier must be `{StaticInputIdentifier.datasamples}` "
                     f"but was set to {values['identifier']}"
                 )
-
         else:
-            if StaticInputIdentifier.has_value(values.get("identifier")):
+            if StaticInputIdentifier.has_value(values["identifier"]):
                 raise ValueError(
-                    f"Inputs of kind {values.get('kind')} cannot have an identifier among the flowing: "
+                    f"Inputs of kind {values['kind']} cannot have an identifier among the flowing: "
                     f"{StaticInputIdentifier.values()}"
                 )
 
         return values
 
 
-class AlgoOutputSpec(_Spec):
+class FunctionOutputSpec(_Spec):
     identifier: str
     kind: AssetKind
     multiple: bool
@@ -391,19 +328,37 @@ class AlgoOutputSpec(_Spec):
         return values
 
 
-class AlgoSpec(_Spec):
-    """Specification for creating an algo"""
+class FunctionSpec(_Spec):
+    """Specification for creating an function
+
+    note : metadata field does not accept strings containing '__' as dict key
+    """
 
     name: str
     description: pathlib.Path
     file: pathlib.Path
     permissions: Permissions
     metadata: Optional[Dict[str, str]]
-    category: AlgoCategory
-    inputs: Optional[List[AlgoInputSpec]] = None
-    outputs: Optional[List[AlgoOutputSpec]] = None
+    inputs: Optional[List[FunctionInputSpec]] = None
+    outputs: Optional[List[FunctionOutputSpec]] = None
 
-    type_: typing.ClassVar[Type] = Type.Algo
+    type_: typing.ClassVar[Type] = Type.Function
+
+    @pydantic.validator("inputs")
+    def _check_inputs(cls, v):  # noqa: N805
+        inputs = v or []
+        identifiers = {value.identifier for value in inputs}
+        if len(identifiers) != len(inputs):
+            raise ValueError("Several function inputs cannot have the same identifier.")
+        return v
+
+    @pydantic.validator("outputs")
+    def _check_outputs(cls, v):  # noqa: N805
+        outputs = v or []
+        identifiers = {value.identifier for value in outputs}
+        if len(identifiers) != len(outputs):
+            raise ValueError("Several function outputs cannot have the same identifier.")
+        return v
 
     @contextlib.contextmanager
     def build_request_kwargs(self):
@@ -433,176 +388,47 @@ class AlgoSpec(_Spec):
         )
 
 
-class UpdateAlgoSpec(_Spec):
-    """Specification for updating an algo"""
+class UpdateFunctionSpec(_Spec):
+    """Specification for updating an function"""
 
     name: str
 
-    type_: typing.ClassVar[Type] = Type.Algo
+    type_: typing.ClassVar[Type] = Type.Function
 
 
-class _TupleSpec(_Spec):
+class TaskSpec(_Spec):
     key: str = pydantic.Field(default_factory=lambda: str(uuid.uuid4()))
     tag: Optional[str]
     compute_plan_key: Optional[str]
     metadata: Optional[Dict[str, str]]
-    algo_key: str
+    function_key: str
+    worker: str
+    rank: Optional[int] = None
     inputs: Optional[List[InputRef]]
     outputs: Optional[Dict[str, ComputeTaskOutputSpec]]
 
+    type_: typing.ClassVar[Type] = Type.Task
+
     @contextlib.contextmanager
     def build_request_kwargs(self):
         # default values are not dumped when `exclude_unset` flag is enabled,
         # this is why we need to reimplement this custom function.
         data = json.loads(self.json(exclude_unset=True))
         data["key"] = self.key
-        data["category"] = self.category
         data["inputs"] = [input.dict() for input in self.inputs] if self.inputs else []
         data["outputs"] = {k: v.dict(by_alias=True) for k, v in self.outputs.items()} if self.outputs else {}
         yield data, None
 
-
-class TraintupleSpec(_TupleSpec):
-    """Specification for creating a traintuple"""
-
-    data_manager_key: str
-    train_data_sample_keys: List[str]
-    in_models_keys: Optional[List[str]]
-    rank: Optional[int]  # Rank of the traintuple in the compute plan
-    category: TaskCategory = pydantic.Field(TaskCategory.train, const=True)
-
-    compute_plan_attr_name: typing.ClassVar[str] = "traintuple_keys"
-    type_: typing.ClassVar[Type] = Type.Traintuple
-
     @classmethod
-    def from_compute_plan(cls, compute_plan_key: str, rank: int, spec: ComputePlanTraintupleSpec) -> "TraintupleSpec":
-        return TraintupleSpec(
-            key=spec.traintuple_id,
-            algo_key=spec.algo_key,
-            data_manager_key=spec.data_manager_key,
-            train_data_sample_keys=spec.train_data_sample_keys,
-            in_models_keys=spec.in_models_ids or list(),
+    def from_compute_plan(cls, compute_plan_key: str, rank: int, spec: ComputePlanTaskSpec) -> "TaskSpec":
+        return TaskSpec(
+            key=spec.task_id,
+            function_key=spec.function_key,
             inputs=spec.inputs,
             outputs=spec.outputs,
             tag=spec.tag,
             compute_plan_key=compute_plan_key,
             rank=rank,
             metadata=spec.metadata,
-        )
-
-
-class AggregatetupleSpec(_TupleSpec):
-    """Specification for creating an aggregate tuple"""
-
-    worker: str
-    in_models_keys: List[str]
-    rank: Optional[int]
-    category: TaskCategory = pydantic.Field(TaskCategory.aggregate, const=True)
-
-    compute_plan_attr_name: typing.ClassVar[str] = "aggregatetuple_keys"
-    type_: typing.ClassVar[Type] = Type.Aggregatetuple
-
-    @classmethod
-    def from_compute_plan(
-        cls, compute_plan_key: str, rank: int, spec: ComputePlanAggregatetupleSpec
-    ) -> "AggregatetupleSpec":
-        return AggregatetupleSpec(
-            key=spec.aggregatetuple_id,
-            algo_key=spec.algo_key,
             worker=spec.worker,
-            in_models_keys=spec.in_models_ids or list(),
-            inputs=spec.inputs,
-            outputs=spec.outputs,
-            tag=spec.tag,
-            compute_plan_key=compute_plan_key,
-            rank=rank,
-            metadata=spec.metadata,
-        )
-
-
-class CompositeTraintupleSpec(_TupleSpec):
-    """Specification for creating a composite traintuple"""
-
-    data_manager_key: str
-    train_data_sample_keys: List[str]
-    in_head_model_key: Optional[str]
-    in_trunk_model_key: Optional[str]
-    rank: Optional[int]
-    category: TaskCategory = pydantic.Field(TaskCategory.composite, const=True)
-
-    compute_plan_attr_name: typing.ClassVar[str] = "composite_traintuple_keys"
-    type_: typing.ClassVar[Type] = Type.CompositeTraintuple
-
-    @classmethod
-    def from_compute_plan(
-        cls, compute_plan_key: str, rank: int, spec: ComputePlanCompositeTraintupleSpec
-    ) -> "CompositeTraintupleSpec":
-        return CompositeTraintupleSpec(
-            key=spec.composite_traintuple_id,
-            algo_key=spec.algo_key,
-            data_manager_key=spec.data_manager_key,
-            train_data_sample_keys=spec.train_data_sample_keys,
-            in_head_model_key=spec.in_head_model_id,
-            in_trunk_model_key=spec.in_trunk_model_id,
-            inputs=spec.inputs,
-            outputs=spec.outputs,
-            tag=spec.tag,
-            compute_plan_key=compute_plan_key,
-            rank=rank,
-            metadata=spec.metadata,
-        )
-
-
-class PredicttupleSpec(_TupleSpec):
-    """Specification for creating a predict tuple"""
-
-    traintuple_key: str
-    data_manager_key: str
-    test_data_sample_keys: List[str]
-    category: TaskCategory = pydantic.Field(TaskCategory.predict, const=True)
-
-    compute_plan_attr_name: typing.ClassVar[str] = "predicttuple_keys"
-    type_: typing.ClassVar[Type] = Type.Predicttuple
-
-    @classmethod
-    def from_compute_plan(
-        cls, compute_plan_key: str, rank: int, spec: ComputePlanPredicttupleSpec
-    ) -> "PredicttupleSpec":
-        return PredicttupleSpec(
-            key=spec.predicttuple_id,
-            algo_key=spec.algo_key,
-            traintuple_key=spec.traintuple_id,
-            inputs=spec.inputs,
-            outputs=spec.outputs,
-            tag=spec.tag,
-            data_manager_key=spec.data_manager_key,
-            test_data_sample_keys=spec.test_data_sample_keys,
-            compute_plan_key=compute_plan_key,
-            metadata=spec.metadata,
-            rank=rank,
-        )
-
-
-class TesttupleSpec(_TupleSpec):
-    """Specification for creating a testtuple"""
-
-    predicttuple_key: str
-    data_manager_key: str
-    test_data_sample_keys: List[str]
-    category: TaskCategory = pydantic.Field(TaskCategory.test, const=True)
-
-    type_: typing.ClassVar[Type] = Type.Testtuple
-
-    @classmethod
-    def from_compute_plan(cls, compute_plan_key: str, spec: ComputePlanTesttupleSpec) -> "TesttupleSpec":
-        return TesttupleSpec(
-            algo_key=spec.algo_key,
-            predicttuple_key=spec.predicttuple_id,
-            inputs=spec.inputs,
-            outputs=spec.outputs,
-            tag=spec.tag,
-            data_manager_key=spec.data_manager_key,
-            test_data_sample_keys=spec.test_data_sample_keys,
-            compute_plan_key=compute_plan_key,
-            metadata=spec.metadata,
         )
