@@ -1,15 +1,25 @@
 from enum import Enum
 
-from substra.sdk.schemas import AlgoInputSpec
-from substra.sdk.schemas import AlgoOutputSpec
 from substra.sdk.schemas import AssetKind
 from substra.sdk.schemas import ComputeTaskOutputSpec
+from substra.sdk.schemas import FunctionInputSpec
+from substra.sdk.schemas import FunctionOutputSpec
 from substra.sdk.schemas import InputRef
 from substra.sdk.schemas import Permissions
 
 PUBLIC_PERMISSIONS = Permissions(public=True, authorized_ids=[])
 
-FL_ALGO_PREDICT_COMPOSITE = "ALGO_PREDICT_COMPOSITE"
+
+class FunctionCategory(str, Enum):
+    """Function category"""
+
+    unknown = "FUNCTION_UNKNOWN"
+    simple = "FUNCTION_SIMPLE"
+    composite = "FUNCTION_COMPOSITE"
+    aggregate = "FUNCTION_AGGREGATE"
+    metric = "FUNCTION_METRIC"
+    predict = "FUNCTION_PREDICT"
+    predict_composite = "FUNCTION_PREDICT_COMPOSITE"
 
 
 class InputIdentifiers(str, Enum):
@@ -21,8 +31,6 @@ class InputIdentifiers(str, Enum):
     performance = "performance"
     opener = "opener"
     datasamples = "datasamples"
-    X = "X"
-    y = "y"
 
 
 class OutputIdentifiers(str, Enum):
@@ -33,95 +41,107 @@ class OutputIdentifiers(str, Enum):
     performance = "performance"
 
 
-class FLAlgoInputs(list, Enum):
-    """Substra algo inputs by algo category based on the InputIdentifiers"""
+class FLFunctionInputs(list, Enum):
+    """Substra function inputs by function category based on the InputIdentifiers"""
 
-    ALGO_AGGREGATE = [
-        AlgoInputSpec(identifier=InputIdentifiers.models, kind=AssetKind.model.value, optional=False, multiple=True)
+    FUNCTION_AGGREGATE = [
+        FunctionInputSpec(identifier=InputIdentifiers.models, kind=AssetKind.model.value, optional=False, multiple=True)
     ]
-    ALGO_SIMPLE = [
-        AlgoInputSpec(
+    FUNCTION_SIMPLE = [
+        FunctionInputSpec(
             identifier=InputIdentifiers.datasamples,
             kind=AssetKind.data_sample.value,
             optional=False,
             multiple=True,
         ),
-        AlgoInputSpec(
+        FunctionInputSpec(
             identifier=InputIdentifiers.opener, kind=AssetKind.data_manager.value, optional=False, multiple=False
         ),
-        AlgoInputSpec(identifier=InputIdentifiers.models, kind=AssetKind.model.value, optional=True, multiple=True),
+        FunctionInputSpec(identifier=InputIdentifiers.models, kind=AssetKind.model.value, optional=True, multiple=True),
     ]
-    ALGO_COMPOSITE = [
-        AlgoInputSpec(
+    FUNCTION_COMPOSITE = [
+        FunctionInputSpec(
             identifier=InputIdentifiers.datasamples,
             kind=AssetKind.data_sample.value,
             optional=False,
             multiple=True,
         ),
-        AlgoInputSpec(
+        FunctionInputSpec(
             identifier=InputIdentifiers.opener, kind=AssetKind.data_manager.value, optional=False, multiple=False
         ),
-        AlgoInputSpec(identifier=InputIdentifiers.local, kind=AssetKind.model.value, optional=True, multiple=False),
-        AlgoInputSpec(identifier=InputIdentifiers.shared, kind=AssetKind.model.value, optional=True, multiple=False),
+        FunctionInputSpec(identifier=InputIdentifiers.local, kind=AssetKind.model.value, optional=True, multiple=False),
+        FunctionInputSpec(
+            identifier=InputIdentifiers.shared, kind=AssetKind.model.value, optional=True, multiple=False
+        ),
     ]
-    ALGO_PREDICT = [
-        AlgoInputSpec(
+    FUNCTION_PREDICT = [
+        FunctionInputSpec(
             identifier=InputIdentifiers.datasamples,
             kind=AssetKind.data_sample.value,
             optional=False,
             multiple=True,
         ),
-        AlgoInputSpec(
+        FunctionInputSpec(
             identifier=InputIdentifiers.opener, kind=AssetKind.data_manager.value, optional=False, multiple=False
         ),
-        AlgoInputSpec(identifier=InputIdentifiers.models, kind=AssetKind.model.value, optional=False, multiple=False),
+        FunctionInputSpec(
+            identifier=InputIdentifiers.model, kind=AssetKind.model.value, optional=False, multiple=False
+        ),
     ]
-    ALGO_PREDICT_COMPOSITE = [
-        AlgoInputSpec(
+    FUNCTION_PREDICT_COMPOSITE = [
+        FunctionInputSpec(
             identifier=InputIdentifiers.datasamples,
             kind=AssetKind.data_sample.value,
             optional=False,
             multiple=True,
         ),
-        AlgoInputSpec(
+        FunctionInputSpec(
             identifier=InputIdentifiers.opener, kind=AssetKind.data_manager.value, optional=False, multiple=False
         ),
-        AlgoInputSpec(identifier=InputIdentifiers.local, kind=AssetKind.model.value, optional=False, multiple=False),
-        AlgoInputSpec(identifier=InputIdentifiers.shared, kind=AssetKind.model.value, optional=False, multiple=False),
+        FunctionInputSpec(
+            identifier=InputIdentifiers.local, kind=AssetKind.model.value, optional=False, multiple=False
+        ),
+        FunctionInputSpec(
+            identifier=InputIdentifiers.shared, kind=AssetKind.model.value, optional=False, multiple=False
+        ),
     ]
-    ALGO_METRIC = [
-        AlgoInputSpec(
+    FUNCTION_METRIC = [
+        FunctionInputSpec(
             identifier=InputIdentifiers.datasamples,
             kind=AssetKind.data_sample.value,
             optional=False,
             multiple=True,
         ),
-        AlgoInputSpec(
+        FunctionInputSpec(
             identifier=InputIdentifiers.opener, kind=AssetKind.data_manager.value, optional=False, multiple=False
         ),
-        AlgoInputSpec(
+        FunctionInputSpec(
             identifier=InputIdentifiers.predictions, kind=AssetKind.model.value, optional=False, multiple=False
         ),
     ]
 
 
-class FLAlgoOutputs(list, Enum):
-    """Substra algo outputs by algo category based on the OutputIdentifiers"""
+class FLFunctionOutputs(list, Enum):
+    """Substra function outputs by function category based on the OutputIdentifiers"""
 
-    ALGO_AGGREGATE = [AlgoOutputSpec(identifier=OutputIdentifiers.model, kind=AssetKind.model.value, multiple=False)]
-    ALGO_SIMPLE = [AlgoOutputSpec(identifier=OutputIdentifiers.model, kind=AssetKind.model.value, multiple=False)]
-    ALGO_COMPOSITE = [
-        AlgoOutputSpec(identifier=OutputIdentifiers.local, kind=AssetKind.model.value, multiple=False),
-        AlgoOutputSpec(identifier=OutputIdentifiers.shared, kind=AssetKind.model.value, multiple=False),
+    FUNCTION_AGGREGATE = [
+        FunctionOutputSpec(identifier=OutputIdentifiers.model, kind=AssetKind.model.value, multiple=False)
     ]
-    ALGO_PREDICT = [
-        AlgoOutputSpec(identifier=OutputIdentifiers.predictions, kind=AssetKind.model.value, multiple=False)
+    FUNCTION_SIMPLE = [
+        FunctionOutputSpec(identifier=OutputIdentifiers.model, kind=AssetKind.model.value, multiple=False)
     ]
-    ALGO_PREDICT_COMPOSITE = [
-        AlgoOutputSpec(identifier=OutputIdentifiers.predictions, kind=AssetKind.model.value, multiple=False)
+    FUNCTION_COMPOSITE = [
+        FunctionOutputSpec(identifier=OutputIdentifiers.local, kind=AssetKind.model.value, multiple=False),
+        FunctionOutputSpec(identifier=OutputIdentifiers.shared, kind=AssetKind.model.value, multiple=False),
     ]
-    ALGO_METRIC = [
-        AlgoOutputSpec(identifier=OutputIdentifiers.performance, kind=AssetKind.performance.value, multiple=False)
+    FUNCTION_PREDICT = [
+        FunctionOutputSpec(identifier=OutputIdentifiers.predictions, kind=AssetKind.model.value, multiple=False)
+    ]
+    FUNCTION_PREDICT_COMPOSITE = [
+        FunctionOutputSpec(identifier=OutputIdentifiers.predictions, kind=AssetKind.model.value, multiple=False)
+    ]
+    FUNCTION_METRIC = [
+        FunctionOutputSpec(identifier=OutputIdentifiers.performance, kind=AssetKind.performance.value, multiple=False)
     ]
 
 
@@ -139,7 +159,7 @@ class FLTaskInputGenerator:
         ]
 
     @staticmethod
-    def tuple(opener_key, data_sample_keys):
+    def task(opener_key, data_sample_keys):
         return FLTaskInputGenerator.opener(opener_key=opener_key) + FLTaskInputGenerator.data_samples(
             data_sample_keys=data_sample_keys
         )
@@ -170,7 +190,7 @@ class FLTaskInputGenerator:
     def train_to_predict(model_key):
         return [
             InputRef(
-                identifier=InputIdentifiers.models,
+                identifier=InputIdentifiers.model,
                 parent_task_key=model_key,
                 parent_task_output_identifier=OutputIdentifiers.model,
             )
@@ -289,19 +309,19 @@ class FLTaskOutputGenerator:
     "Generates task outputs based on Input and OutputIdentifiers"
 
     @staticmethod
-    def traintuple(authorized_ids=None):
+    def traintask(authorized_ids=None):
         return {OutputIdentifiers.model: ComputeTaskOutputSpec(permissions=_permission_from_ids(authorized_ids))}
 
     @staticmethod
-    def aggregatetuple(authorized_ids=None):
+    def aggregatetask(authorized_ids=None):
         return {OutputIdentifiers.model: ComputeTaskOutputSpec(permissions=_permission_from_ids(authorized_ids))}
 
     @staticmethod
-    def predicttuple(authorized_ids=None):
+    def predicttask(authorized_ids=None):
         return {OutputIdentifiers.predictions: ComputeTaskOutputSpec(permissions=_permission_from_ids(authorized_ids))}
 
     @staticmethod
-    def testtuple(authorized_ids=None):
+    def testtask(authorized_ids=None):
         return {
             OutputIdentifiers.performance: ComputeTaskOutputSpec(
                 permissions=Permissions(public=True, authorized_ids=[])
@@ -309,7 +329,7 @@ class FLTaskOutputGenerator:
         }
 
     @staticmethod
-    def composite_traintuple(shared_authorized_ids=None, local_authorized_ids=None):
+    def composite_traintask(shared_authorized_ids=None, local_authorized_ids=None):
         return {
             OutputIdentifiers.shared: ComputeTaskOutputSpec(permissions=_permission_from_ids(shared_authorized_ids)),
             OutputIdentifiers.local: ComputeTaskOutputSpec(permissions=_permission_from_ids(local_authorized_ids)),
