@@ -1,17 +1,3 @@
-# Copyright 2018 Owkin, inc.
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#      http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
-
 import pydantic
 import pytest
 
@@ -58,13 +44,13 @@ def test_add_dataset_409_success(client, dataset_query, mocker):
     assert key == datastore.DATASET["key"]
 
 
-def test_add_algo(client, algo_query, mocker):
-    m_post = mock_requests(mocker, "post", response=datastore.ALGO)
-    m_get = mock_requests(mocker, "get", response=datastore.ALGO)
-    key = client.add_algo(algo_query)
-    response = client.get_algo(key)
+def test_add_function(client, function_query, mocker):
+    m_post = mock_requests(mocker, "post", response=datastore.FUNCTION)
+    m_get = mock_requests(mocker, "get", response=datastore.FUNCTION)
+    key = client.add_function(function_query)
+    response = client.get_function(key)
 
-    assert response == models.Algo(**datastore.ALGO)
+    assert response == models.Function(**datastore.FUNCTION)
     m_post.assert_called()
     m_get.assert_called()
 
