@@ -16,7 +16,7 @@ from ..utils import mock_response
     "asset_type",
     [
         ("dataset"),
-        ("algo"),
+        ("function"),
         ("model"),
     ],
 )
@@ -35,7 +35,7 @@ def test_download_asset(asset_type, tmp_path, client, mocker):
     m.assert_called()
 
 
-@pytest.mark.parametrize("asset_type", ["dataset", "algo", "model", "logs"])
+@pytest.mark.parametrize("asset_type", ["dataset", "function", "model", "logs"])
 def test_download_asset_not_found(asset_type, tmp_path, client, mocker):
     m = mock_requests(mocker, "get", status=404)
 
@@ -46,7 +46,7 @@ def test_download_asset_not_found(asset_type, tmp_path, client, mocker):
     assert m.call_count == 1
 
 
-@pytest.mark.parametrize("asset_type", ["dataset", "algo", "model"])
+@pytest.mark.parametrize("asset_type", ["dataset", "function", "model"])
 def test_download_content_not_found(asset_type, tmp_path, client, mocker):
     item = getattr(datastore, asset_type.upper())
 
@@ -71,16 +71,16 @@ def test_download_content_not_found(asset_type, tmp_path, client, mocker):
 
 
 @pytest.mark.parametrize(
-    "method_name, asset_type",
+    "asset_type, identifier",
     [
-        ("download_model_from_traintuple", "TRAINTUPLE"),
-        ("download_model_from_aggregatetuple", "AGGREGATETUPLE"),
-        ("download_head_model_from_composite_traintuple", "COMPOSITE_TRAINTUPLE"),
-        ("download_trunk_model_from_composite_traintuple", "COMPOSITE_TRAINTUPLE"),
+        ("TRAINTASK", "model"),
+        ("AGGREGATETASK", "model"),
+        ("COMPOSITE_TRAINTASK", "local"),
+        ("COMPOSITE_TRAINTASK", "shared"),
     ],
 )
 @patch.object(Client, "download_model")
-def test_download_model_from_tuple(fake_download_model, tmp_path, client, method_name, asset_type, mocker):
+def test_download_model_from_task(fake_download_model, tmp_path, client, asset_type, identifier, mocker):
     item = getattr(datastore, asset_type)
     responses = [
         mock_response(item),  # metadata
@@ -89,8 +89,7 @@ def test_download_model_from_tuple(fake_download_model, tmp_path, client, method
 
     m = mock_requests_responses(mocker, "get", responses)
 
-    method = getattr(client, method_name)
-    method("key", tmp_path)
+    client.download_model_from_task("key", identifier, tmp_path)
 
     m.assert_called
     assert fake_download_model.call_count == 1
@@ -98,15 +97,15 @@ def test_download_model_from_tuple(fake_download_model, tmp_path, client, method
 
 def test_download_logs(tmp_path, client, mocker):
     logs = b"Lorem ipsum dolor sit amet"
-    tuple_key = "key"
+    task_key = "key"
 
     response = mock_response(logs)
     response.iter_content.return_value = [logs]
 
     m = mock_requests_responses(mocker, "get", [response])
-    client.download_logs(tuple_key, tmp_path)
+    client.download_logs(task_key, tmp_path)
 
     m.assert_called_once()
     response.iter_content.assert_called_once()
 
-    assert (tmp_path / f"tuple_logs_{tuple_key}.txt").read_bytes() == logs
+    assert (tmp_path / f"task_logs_{task_key}.txt").read_bytes() == logs
