@@ -17,12 +17,7 @@ from ..utils import mock_response
         "model",
         "dataset",
         "data_sample",
-        "algo",
-        "predicttuple",
-        "testtuple",
-        "traintuple",
-        "aggregatetuple",
-        "composite_traintuple",
+        "function",
         "compute_plan",
     ],
 )
@@ -38,6 +33,27 @@ def test_get_asset(asset_type, client, mocker):
     m.assert_called()
 
 
+@pytest.mark.parametrize(
+    "asset_type",
+    [
+        "predicttask",
+        "testtask",
+        "traintask",
+        "aggregatetask",
+        "composite_traintask",
+    ],
+)
+def test_get_task(asset_type, client, mocker):
+    item = getattr(datastore, asset_type.upper())
+
+    m = mock_requests(mocker, "get", response=item)
+
+    response = client.get_task("magic-key")
+
+    assert response == models.SCHEMA_TO_MODEL[schemas.Type.Task](**item)
+    m.assert_called()
+
+
 def test_get_asset_not_found(client, mocker):
     mock_requests(mocker, "get", status=404)
 
@@ -49,12 +65,7 @@ def test_get_asset_not_found(client, mocker):
     "asset_type",
     [
         "dataset",
-        "algo",
-        "predicttuple",
-        "testtuple",
-        "traintuple",
-        "aggregatetuple",
-        "composite_traintuple",
+        "function",
         "compute_plan",
         "model",
     ],
@@ -74,13 +85,36 @@ def test_get_extra_field(asset_type, client, mocker):
     m.assert_called()
 
 
+@pytest.mark.parametrize(
+    "asset_type",
+    [
+        "predicttask",
+        "testtask",
+        "traintask",
+        "aggregatetask",
+        "composite_traintask",
+    ],
+)
+def test_get_task_extra_field(asset_type, client, mocker):
+    item = getattr(datastore, asset_type.upper())
+    raw = getattr(datastore, asset_type.upper()).copy()
+    raw["unknown_extra_field"] = "some value"
+
+    m = mock_requests(mocker, "get", response=raw)
+
+    response = client.get_task("magic-key")
+
+    assert response == models.SCHEMA_TO_MODEL[schemas.Type.Task](**item)
+    m.assert_called()
+
+
 def test_get_logs(client, mocker):
     logs = "Lorem ipsum dolor sit amet"
-    tuple_key = "key"
+    task_key = "key"
 
     responses = [mock_response(logs)]
     m = mock_requests_responses(mocker, "get", responses)
-    result = client.get_logs(tuple_key)
+    result = client.get_logs(task_key)
 
     m.assert_called_once()
     assert result == logs
