@@ -1,16 +1,3 @@
-# Copyright 2018 Owkin, inc.
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#      http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
 import json
 
 import pytest
@@ -86,7 +73,7 @@ def test_request_connection_error(mocker):
 
 
 def test_add_timeout_with_retry(mocker):
-    asset_type = "traintuple"
+    asset_type = "traintask"
     responses = [
         mock_response(response={"key": "a-key"}, status=408),
         mock_response(response={"key": "a-key"}),
@@ -98,7 +85,7 @@ def test_add_timeout_with_retry(mocker):
 
 
 def test_add_already_exist(mocker):
-    asset_type = "traintuple"
+    asset_type = "traintask"
     m_post = mock_requests(mocker, "post", response={"key": "a-key"}, status=409)
     asset = _client_from_config(CONFIG).add(asset_type)
     assert len(m_post.call_args_list) == 1
@@ -117,8 +104,8 @@ def test_add_wrong_url(mocker):
 
 
 def test_list_paginated(mocker):
-    asset_type = "traintuple"
-    items = [datastore.TRAINTUPLE, datastore.TRAINTUPLE]
+    asset_type = "traintask"
+    items = [datastore.TRAINTASK, datastore.TRAINTASK]
     responses = [
         mock_response(
             response={
@@ -146,8 +133,8 @@ def test_list_paginated(mocker):
 
 
 def test_list_not_paginated(mocker):
-    asset_type = "traintuple"
-    items = [datastore.TRAINTUPLE, datastore.TRAINTUPLE]
+    asset_type = "traintask"
+    items = [datastore.TRAINTASK, datastore.TRAINTASK]
     m_get = mock_requests(
         mocker,
         "get",
